==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/it.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Il nome dell'etichetta è vuoto",
    "Update" : "Aggiorna",
    "Create" : "Crea",
    "Select tag …" : "Seleziona etichetta...",
    "System tag %1$s added by the system" : "Etichetta di sistema %1$s aggiunta dal sistema",
    "Added system tag {systemtag}" : "Aggiunta l'etichetta di sistema {systemtag}",
    "Added system tag %1$s" : "Aggiunta l'etichetta di sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha aggiunto l'etichetta di sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etichetta di sistema %1$s rimossa dal sistema",
    "Removed system tag {systemtag}" : "Etichetta di sistema {systemtag} rimossa",
    "Removed system tag %1$s" : "Etichetta di sistema %1$s rimossa",
    "%1$s removed system tag %2$s" : "%1$s ha rimosso l'etichetta di sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha rimosso l'etichetta di sistema {systemtag}",
    "You created system tag %1$s" : "Hai creato l'etichetta di sistema %1$s",
    "You created system tag {systemtag}" : "Hai creato l'etichetta di sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creato l'etichetta di sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creato l'etichetta di sistema {systemtag}",
    "You deleted system tag %1$s" : "Hai eliminato l'etichetta di sistema %1$s",
    "You deleted system tag {systemtag}" : "Hai eliminato l'etichetta di sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha eliminato l'etichetta di sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha eliminato l'etichetta di sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Hai aggiornato l'etichetta di sistema %2$s in %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Hai aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha aggiornato l'etichetta di sistema %3$s in %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'etichetta di sistema %2$s è stata aggiunta a %1$s dal sistema",
    "System tag {systemtag} was added to {file} by the system" : "L'etichetta di sistema {systemtag} è stata aggiunta a {file} dal sistema",
    "You added system tag %2$s to %1$s" : "Hai aggiunto l'etichetta di sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Hai aggiunto l'etichetta di sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha aggiunto l'etichetta di sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'etichetta di sistema %2$s è stata rimossa da %1$s dal sistema",
    "System tag {systemtag} was removed from {file} by the system" : "L'etichetta di sistema {systemtag} è stata rimossa da {file} dal sistema",
    "You removed system tag %2$s from %1$s" : "Hai rimosso l'etichetta di sistema %2$s da %1$s",
    "You removed system tag {systemtag} from {file}" : "Hai rimosso l'etichetta di sistema {systemtag} da {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha rimosso l'etichetta di sistema %3$s da %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha rimosso l'etichetta di sistema {systemtag} da {file}",
    "%s (restricted)" : "%s (limitato)",
    "%s (invisible)" : "%s (invisibile)",
    "<strong>System tags</strong> for a file have been modified" : "Le <strong>etichette di sistema</strong> per un file sono state modificate",
    "Tags" : "Etichette",
    "All tagged %s …" : "Tutti etichettati %s …",
    "tagged %s" : "etichettato %s",
    "Collaborative tags" : "Etichette collaborative",
    "Collaborative tagging functionality which shares tags among users." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
    "Loading collaborative tags …" : "Caricamento etichette collaborative …",
    "Search or create collaborative tags" : "Cerca o crea etichette collaborative",
    "Collaborative tags …" : "Etichette collaborative …",
    "No tags to select, type to create a new tag" : "Nessuna etichetta da selezionare, digita per crearne una nuova",
    "Failed to load tags" : "Caricamento etichette non riuscito",
    "Failed to load selected tags" : "Caricamento etichette selezionate fallito",
    "Failed to select tag" : "Selezione etichetta fallita",
    "Failed to create tag" : "Creazione etichetta fallita",
    "Failed to delete tag" : "Eliminazione etichetta fallita",
    "This file has the tag {tag}" : "Questo file ha il tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Il file ha i tag {firstTags} e {lastTag}",
    "Failed to load last used tags" : "Caricamento ultime etichette usate fallito",
    "Missing \"Content-Location\" header" : "Intestazione \"Content-Location\" mancante",
    "Tagged files" : "File etichettati",
    "Select tags to filter by" : "Seleziona le etichette per filtrare",
    "No tags found" : "Nessuna etichetta trovata",
    "Please select tags to filter by" : "Seleziona le etichette per filtrare",
    "No files found for the selected tags" : "Nessun file trovato per le etichette selezionate",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per uso interno, poiché gli utenti non possono vederle o assegnarle.",
    "Create a new tag" : "Crea una nuova etichetta",
    "Name" : "Nome",
    "Public" : "Pubblico",
    "Restricted" : "Limitato",
    "Invisible" : "invisibile",
    "Delete" : "Elimina",
    "Reset" : "Ripristina",
    "No files in here" : "Qui non c'è alcun file",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Size" : "Dimensione",
    "Modified" : "Modificato"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-26.0.9.tgz: nextcloud/apps/systemtags/l10n/it.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etichetta di sistema %1$s aggiunta dal sistema",
    "Added system tag {systemtag}" : "Aggiunta l'etichetta di sistema {systemtag}",
    "Added system tag %1$s" : "Aggiunta l'etichetta di sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha aggiunto l'etichetta di sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etichetta di sistema %1$s rimossa dal sistema",
    "Removed system tag {systemtag}" : "Etichetta di sistema {systemtag} rimossa",
    "Removed system tag %1$s" : "Etichetta di sistema %1$s rimossa",
    "%1$s removed system tag %2$s" : "%1$s ha rimosso l'etichetta di sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha rimosso l'etichetta di sistema {systemtag}",
    "You created system tag %1$s" : "Hai creato l'etichetta di sistema %1$s",
    "You created system tag {systemtag}" : "Hai creato l'etichetta di sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creato l'etichetta di sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creato l'etichetta di sistema {systemtag}",
    "You deleted system tag %1$s" : "Hai eliminato l'etichetta di sistema %1$s",
    "You deleted system tag {systemtag}" : "Hai eliminato l'etichetta di sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha eliminato l'etichetta di sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha eliminato l'etichetta di sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Hai aggiornato l'etichetta di sistema %2$s in %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Hai aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha aggiornato l'etichetta di sistema %3$s in %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha aggiornato l'etichetta di sistema {oldsystemtag} in {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "L'etichetta di sistema %2$s è stata aggiunta a %1$s dal sistema",
    "System tag {systemtag} was added to {file} by the system" : "L'etichetta di sistema {systemtag} è stata aggiunta a {file} dal sistema",
    "You added system tag %2$s to %1$s" : "Hai aggiunto l'etichetta di sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Hai aggiunto l'etichetta di sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha aggiunto l'etichetta di sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha aggiunto l'etichetta di sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "L'etichetta di sistema %2$s è stata rimossa da %1$s dal sistema",
    "System tag {systemtag} was removed from {file} by the system" : "L'etichetta di sistema {systemtag} è stata rimossa da {file} dal sistema",
    "You removed system tag %2$s from %1$s" : "Hai rimosso l'etichetta di sistema %2$s da %1$s",
    "You removed system tag {systemtag} from {file}" : "Hai rimosso l'etichetta di sistema {systemtag} da {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha rimosso l'etichetta di sistema %3$s da %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha rimosso l'etichetta di sistema {systemtag} da {file}",
    "%s (restricted)" : "%s (limitato)",
    "%s (invisible)" : "%s (invisibile)",
    "<strong>System tags</strong> for a file have been modified" : "Le <strong>etichette di sistema</strong> per un file sono state modificate",
    "Tags" : "Etichette",
    "All tagged %s …" : "Tutti etichettati %s …",
    "tagged %s" : "etichettato %s",
    "Collaborative tags" : "Etichette collaborative",
    "Collaborative tagging functionality which shares tags among users." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
    "Collaborative tags …" : "Etichette collaborative …",
    "Tag name" : "Nome etichetta",
    "Tag level" : "Livello etichetta",
    "Create" : "Crea",
    "Update" : "Aggiorna",
    "Delete" : "Elimina",
    "Reset" : "Ripristina",
    "Loading …" : "Caricamento …",
    "Public" : "Pubblico",
    "Restricted" : "Limitato",
    "Invisible" : "invisibile",
    "Failed to create tag" : "Creazione etichetta fallita",
    "Failed to delete tag" : "Eliminazione etichetta fallita",
    "Loading collaborative tags …" : "Caricamento etichette collaborative …",
    "Search or create collaborative tags" : "Cerca o crea etichette collaborative",
    "No tags to select, type to create a new tag" : "Nessuna etichetta da selezionare, digita per crearne una nuova",
    "Failed to load tags" : "Caricamento etichette non riuscito",
    "Failed to load selected tags" : "Caricamento etichette selezionate fallito",
    "Failed to select tag" : "Selezione etichetta fallita",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per uso interno, poiché gli utenti non possono vederle o assegnarle.",
    "This file has the tag {tag}" : "Questo file ha il tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Il file ha i tag {firstTags} e {lastTag}",
    "List of tags and their associated files and folders." : "Lista di etichette e dei loro file e cartelle associati.",
    "No tags found" : "Nessuna etichetta trovata",
    "Tags you have created will show up here." : "Le etichette che hai creato saranno mostrate qui.",
    "Failed to load last used tags" : "Caricamento ultime etichette usate fallito",
    "Missing \"Content-Location\" header" : "Intestazione \"Content-Location\" mancante",
    "No files in here" : "Qui non c'è alcun file",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "Tag name is empty" : "Il nome dell'etichetta è vuoto",
    "Select tag …" : "Seleziona etichetta...",
    "Tagged files" : "File etichettati",
    "Select tags to filter by" : "Seleziona le etichette per filtrare",
    "Please select tags to filter by" : "Seleziona le etichette per filtrare",
    "No files found for the selected tags" : "Nessun file trovato per le etichette selezionate",
    "Create a new tag" : "Crea una nuova etichetta"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
